#ifndef STRUCT_DRIVE_PATH_H
#define STRUCT_DRIVE_PATH_H

// ドライブのデバイスファイルとマウントポイントのパスと、
// ファイルシステムの種類を入れる構造体
typedef struct drive_path
{
	char *device;
	char *mount_point;
	char *fs;
} DPath;

#endif
